..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_access.ext
   :members:

Action factory
--------------

.. automodule:: invenio_access.factory
  :members:

Permissions
-----------

.. autoclass:: invenio_access.permissions.Permission
   :members:

Needs
-----

.. autodata:: invenio_access.permissions.ParameterizedActionNeed

.. autodata:: invenio_access.permissions.SystemRoleNeed

System roles
------------

.. autodata:: invenio_access.permissions.any_user

.. autodata:: invenio_access.permissions.authenticated_user

.. autodata:: invenio_access.loaders.load_permissions_on_identity_loaded

Actions
-------

.. autodata:: invenio_access.permissions.superuser_access

Models
------

.. automodule:: invenio_access.models
   :members:

Utils
-----

.. automodule:: invenio_access.utils
   :members:

Proxies
-------

.. automodule:: invenio_access.proxies
  :members:

CLI
---

.. automodule:: invenio_access.cli
   :members:

.. autodata:: invenio_access.cli.allow_action

.. autodata:: invenio_access.cli.deny_action

.. autodata:: invenio_access.cli.list_actions
